<?php
/*
 * Plugin Name: Pro Sites Extras [Multisite module]
 * Plugin URI: https://hostmijnpagina.nl/
 * Description: Removes delete site and export site menu options for Pro Site and Free Site respectively.
 * Version: 2.0.0
 * Author: Sybre Waaijer
 * Author URI: https://cyberwire.nl/
 */

/*
 * Install this as a php file in /wp-content/mu-plugins/pro-site-extras.php
 * Or network activate it in /wp-content/plugins/prositesextras/pro-site-extras.php
 * This plugin restricts access to the "delete site" option if a user has a Pro Site subscription.
 * This plugin restricts access to the export site function if a user has no Pro Site subscription.
 * There is no WordPress admin menu for this plugin. All menu items should be managed whitin this file.
 */
 
/*
 * Version 1.0 	: Initial release
 * Version 2.0	: Reworked so your site won't crash if you deactivate Pro Sites. Uses a SQL query instead of pro sites hooks.
 * 				: Removed Automattic Domain mapping plugin removal, WPMUdev's far surpasses it as of now so it's not needed.
 *				: Made this plugin have a higher priority so the menu's will be properly removed from view.
 *				: Allows super admin to export the site even if the site is Free.
 */

/* Bonus code: uncomment this line below to allow 404 pages to work again on your main blog if you've set NOBLOGREDIRECT */
// remove_action( 'template_redirect', 'maybe_redirect_404' ); 

function wpmu_remove_menu_pro() {
	global $wpdb,$blog_id;
	
	$prolevelsql = -1; //resets the query
	$prolevelsql = $wpdb->get_var($wpdb->prepare("SELECT level FROM {$wpdb->base_prefix}pro_sites WHERE blog_ID = %d", $blog_id)); //This query is somehow cached? wut.
	
	//* Remove delete from Pro
	if( $prolevelsql > 0 ) { //For all Pro Site Subscriptions
		$page = remove_submenu_page('tools.php', 'ms-delete-site.php'); //Disables delete site menu
		
		if (stripos($_SERVER['REQUEST_URI'],'ms-delete-site.php') !== false) {
			wp_redirect( get_option('siteurl') . '/wp-admin/tools.php?del_permission_denied=true'); //Redirects the removal of site with a big fat notice
		}
	}
	
	//* Remove export from Free
	if( empty($prolevelsql) || $prolevelsql == 0 ) { //Free Level
		if ( !is_super_admin() ) { // Super admin may still export =)
			$page = remove_submenu_page('tools.php', 'export.php'); //Removes export menu
		
			if (stripos($_SERVER['REQUEST_URI'],'export.php') !== false) {
				wp_redirect( get_option('siteurl') . '/wp-admin/tools.php?exp_permission_denied=true'); //Redirects the export of a site with a big fat notice
			}
		}
	}
}
add_action( 'admin_menu', 'wpmu_remove_menu_pro', 999 );

function del_no_permissions_admin_notice() { // delete site notice
		echo "<div id='permissions-warning' class='error fade'><p><strong>".__('Pro Sites cannot delete their website. If you still wish to delete your website please contact us at support@example.com')."</strong></p></div>";
}
function exp_no_permissions_admin_notice() { // export site notice
		echo "<div id='permissions-warning' class='error fade'><p><strong>".__('Free Sites cannot export their content.')."</strong></p></div>";
}

function no_permissions_show_notice() {
	if(isset($_GET['del_permission_denied']) && $_GET['del_permission_denied']) {
		add_action('admin_notices', 'del_no_permissions_admin_notice');
	}
	if(isset($_GET['exp_permission_denied']) && $_GET['exp_permission_denied']) {
		add_action('admin_notices', 'exp_no_permissions_admin_notice');
	}
}

add_action('admin_init','no_permissions_show_notice');